@@ -2,7 +2,7 @@
 #'
 #' Adds infrastructure needed to use the [cpp11](https://cpp11.r-lib.org)
 #' package, a header-only R package that helps R package developers handle R
-#' objects with C++ code. compiled code:
+#' objects with C++ code:
 #'   * Creates `src/`
 #'   * Adds cpp11 to `DESCRIPTION`
 #'   * Creates `src/code.cpp`, an initial placeholder `.cpp` file
@@ -10,11 +10,12 @@
 #' @export
 use_cpp11 <- function() {
   check_is_package("use_cpp11()")
+  check_installed("cpp11")
   check_uses_roxygen("use_cpp11()")
+  check_has_package_doc("use_cpp11()")
   use_src()
 
   use_dependency("cpp11", "LinkingTo")
-  use_system_requirement("C++11")
 
   use_template(
     "code-cpp11.cpp",
@@ -28,8 +29,8 @@ use_cpp11 <- function() {
 }
 
 get_cpp_register_deps <- function() {
-  res <- desc::desc(package = "cpp11")$get_field("Config/Needs/cpp11/cpp_register")
-  strsplit(res, "[[:space:]]*,[[:space:]]*")[[1]]
+  desc <- desc::desc(package = "cpp11")
+  desc$get_list("Config/Needs/cpp11/cpp_register")[[1]]
 }
 
 check_cpp_register_deps <- function() {
@@ -37,6 +38,8 @@ check_cpp_register_deps <- function() {
   installed <- map_lgl(cpp_register_deps, is_installed)
 
   if (!all(installed)) {
-    ui_todo("Now install {ui_value(cpp_register_deps[!installed])} to use cpp11.")
+    ui_bullets(c(
+      "_" = "Now install {.pkg {cpp_register_deps[!installed]}} to use {.pkg cpp11}."
+    ))
   }
 }
