@@ -13,7 +13,7 @@
 
 #' usethis consults the following sources, in this order, to set `DESCRIPTION`
 #' fields:
-#' * `fields` argument of [create_package()] or [use_description()]
+#' * `fields` argument of [create_package()] or `use_description()`
 #' * `getOption("usethis.description")`
 #' * Defaults built into usethis
 #'
@@ -27,11 +27,14 @@
 #' ```
 #' options(
 #'   usethis.description = list(
-#'     `Authors@R` = 'person("Jane", "Doe", email = "jane@example.com",
-#'                           role = c("aut", "cre"),
-#'                           comment = c(ORCID = "YOUR-ORCID-ID"))',
-#'     License = "MIT + file LICENSE",
-#'     Language =  "es"
+#'     "Authors@R" = utils::person(
+#'       "Jane", "Doe",
+#'       email = "jane@example.com",
+#'       role = c("aut", "cre"),
+#'       comment = c(ORCID = "YOUR-ORCID-ID")
+#'     ),
+#'     Language =  "es",
+#'     License = "MIT + file LICENSE"
 #'   )
 #' )
 #' ```
@@ -41,8 +44,9 @@
 #' supported.
 #'
 #' @param fields A named list of fields to add to `DESCRIPTION`, potentially
-#'   overriding default values. See [use_description()] for how you can set
-#'   personalized defaults using package options.
+#'   overriding default values. Default values are taken from the
+#'   `"usethis.description"` option or the usethis package (in that order), and
+#'   can be viewed with `use_description_defaults()`.
 #' @param check_name Whether to check if the name is valid for CRAN and throw an
 #'   error if not.
 #' @param roxygen If `TRUE`, sets `RoxygenNote` to current roxygen2 version
@@ -65,17 +69,7 @@ use_description <- function(fields = list(),
     check_package_name(name)
   }
 
-  desc <- build_description(name, roxygen = roxygen, fields = fields)
-
-  tf <- withr::local_tempfile(pattern = glue("use_description-{name}-"))
-  desc$write(file = tf)
-  tf_contents <- read_utf8(tf)
-  write_over(proj_path("DESCRIPTION"), tf_contents)
-
-  # explicit check of "usethis.quiet" since I'm not doing the printing
-  if (!getOption("usethis.quiet", default = FALSE)) {
-    desc$print()
-  }
+  proj_desc_create(name = name, fields = fields, roxygen = roxygen)
 }
 
 #' @rdname use_description
@@ -87,15 +81,7 @@ use_description_defaults <- function(package = NULL,
   fields <- fields %||% list()
   check_is_named_list(fields)
 
-  usethis <- list(
-    Package = package %||% "valid.package.name.goes.here",
-    Version = "0.0.0.9000",
-    Title = "What the Package Does (One Line, Title Case)",
-    Description = "What the package does (one paragraph).",
-    "Authors@R" = 'person("First", "Last", , "first.last@example.com", c("aut", "cre"), comment = c(ORCID = "YOUR-ORCID-ID"))',
-    License = "`use_mit_license()`, `use_gpl3_license()` or friends to pick a license",
-    Encoding = "UTF-8"
-  )
+  usethis <- usethis_description_defaults(package)
 
   if (roxygen) {
     if (is_installed("roxygen2")) {
@@ -132,22 +118,26 @@ use_description_defaults <- function(package = NULL,
   compact(defaults)
 }
 
-build_description <- function(package, roxygen = TRUE, fields = list()) {
-  fields <- use_description_defaults(package, roxygen = roxygen, fields)
-
-  desc <- desc::desc(text = glue("{names(fields)}: {fields}"))
-  tidy_desc(desc)
-  desc
+usethis_description_defaults <- function(package = NULL) {
+  list(
+    Package = package %||% "valid.package.name.goes.here",
+    Version = "0.0.0.9000",
+    Title = "What the Package Does (One Line, Title Case)",
+    Description = "What the package does (one paragraph).",
+    "Authors@R" = 'person("First", "Last", email = "first.last@example.com", role = c("aut", "cre"))',
+    License = "`use_mit_license()`, `use_gpl3_license()` or friends to pick a license",
+    Encoding = "UTF-8"
+  )
 }
 
 check_package_name <- function(name) {
   if (!valid_package_name(name)) {
-    ui_stop(c(
-      "{ui_value(name)} is not a valid package name. To be allowed on CRAN, it should:",
-      "* Contain only ASCII letters, numbers, and '.'",
-      "* Have at least two characters",
-      "* Start with a letter",
-      "* Not end with '.'"
+    ui_abort(c(
+      "x" = "{.val {name}} is not a valid package name. To be allowed on CRAN, it should:",
+      "*" = "Contain only ASCII letters, numbers, and '.'.",
+      "*" = "Have at least two characters.",
+      "*" = "Start with a letter.",
+      "*" = "Not end with '.'."
     ))
   }
 }
@@ -163,60 +153,3 @@ tidy_desc <- function(desc) {
   # Wrap in a try() so it always succeeds, even if user options are malformed
   try(desc$normalize(), silent = TRUE)
 }
-
-# 2021-10-10, while adding use_description_list(), I moved this helper here
-#
-# this helper feels out-of-sync with current usethis practices around active
-# project and how overwrite is handled
-#
-# I won't change use_description_field() now, but use_description_list() is
-# implemented differently, more in keeping with our current style
-use_description_field <- function(name, value, overwrite = FALSE) {
-  # account for `value`s produced via `glue::glue()`
-  value <- as.character(value)
-  curr <- desc::desc_get(name, file = proj_get())[[1]]
-  curr <- gsub("^\\s*|\\s*$", "", curr)
-
-  if (identical(curr, value)) {
-    return(invisible())
-  }
-
-  if (!is.na(curr) && !overwrite) {
-    ui_stop(
-      "{ui_field(name)} has a different value in DESCRIPTION. \\
-      Use {ui_code('overwrite = TRUE')} to overwrite."
-    )
-  }
-
-  ui_done("Setting {ui_field(name)} field in DESCRIPTION to {ui_value(value)}")
-  desc::desc_set(name, value, file = proj_get())
-  invisible()
-}
-
-use_description_list <- function(key,
-                                 values,
-                                 append = TRUE,
-                                 desc = NULL) {
-  desc_provided <- !is.null(desc)
-  desc <- desc %||% desc::desc(file = proj_get())
-  check_string(key)
-  stopifnot(is.character(values))
-
-  if (append) {
-    values <- unique(c(desc$get_list(key, default = ""), values))
-  }
-  # formatting needs some improvements
-  # https://github.com/r-lib/desc/issues/117
-  desc$set_list(key, values, sep = ",\n")
-
-  if (desc_provided) {
-    return(invisible())
-  }
-
-  tf <- withr::local_tempfile(
-    pattern = glue("use_description_list-{project_name()}-{path_sanitize(key, '-')}")
-  )
-  desc$write(file = tf)
-  tf_contents <- read_utf8(tf)
-  write_over(proj_path("DESCRIPTION"), tf_contents)
-}
