@@ -121,13 +121,15 @@ use_github_action <- function(name = NULL,
   }
 
   if (!is.null(readme)) {
-    ui_todo("Learn more at <{readme}>.")
+    ui_bullets(c("_" = "Learn more at {.url {readme}}."))
   }
 
-  badge <- badge %||% is_check_action(url)
-  if (badge) {
+  if (badge %||% is_check_action(url)) {
     use_github_actions_badge(path_file(save_as))
   }
+  if (badge %||% is_coverage_action(url)) {
+    use_codecov_badge(target_repo_spec())
+  }
 
   invisible(new)
 }
@@ -167,6 +169,10 @@ is_check_action <- function(url) {
   grepl("^check-", path_file(url))
 }
 
+is_coverage_action <- function(url) {
+  grepl("test-coverage", path_file(url))
+}
+
 #' Generates a GitHub Actions badge
 #'
 #' Generates a GitHub Actions badge and that's all. This exists primarily for
@@ -227,11 +233,9 @@ use_tidy_github_actions <- function(ref = NULL) {
   has_appveyor_travis <- file_exists(old_configs)
 
   if (any(has_appveyor_travis)) {
-    if (ui_yeah(
-      "Remove existing {ui_path('.travis.yml')} and {ui_path('appveyor.yml')}?"
-    )) {
+    if (ui_yep("Remove existing {.path .travis.yml} and {.path appveyor.yml}?")) {
       file_delete(old_configs[has_appveyor_travis])
-      ui_todo("Remove old badges from README")
+      ui_bullets(c("_" = "Remove old badges from README."))
     }
   }
 
@@ -250,10 +254,10 @@ check_uses_github_actions <- function() {
     return(invisible())
   }
 
-  ui_stop("
-    Cannot detect that package {ui_value(project_name())} already \\
-    uses GitHub Actions.
-    Do you need to run {ui_code('use_github_actions()')}?")
+  ui_abort(c(
+    "Cannot detect that package {.pkg {project_name()}} already uses GitHub Actions.",
+    "Do you need to run {.run [use_github_action()](usethis::use_github_action())}?"
+  ))
 }
 
 latest_release <- function(repo_spec = "https://github.com/r-lib/actions") {
