@@ -10,6 +10,7 @@ proj_set_ <- function(path) {
 
 #' Utility functions for the active project
 #'
+#' @description
 #' Most `use_*()` functions act on the **active project**. If it is
 #' unset, usethis uses [rprojroot](https://rprojroot.r-lib.org) to
 #' find the project root of the current working directory. It establishes the
@@ -26,6 +27,10 @@ proj_set_ <- function(path) {
 #' [here](https://here.r-lib.org), to programmatically detect a project and
 #' build paths within it.
 #'
+#' If you are puzzled why a path (usually the current working directory) does
+#' *not* appear to be inside project, it can be helpful to call
+#' `here::dr_here()` to get much more verbose feedback.
+#'
 #' @name proj_utils
 #' @family project functions
 #' @examples
@@ -69,32 +74,39 @@ proj_get <- function() {
 #'   adding a `DESCRIPTION` file.
 #' @export
 proj_set <- function(path = ".", force = FALSE) {
-  if (dir_exists(path %||% "") && is_in_proj(path)) {
+  if (!force && dir_exists(path %||% "") && is_in_proj(path)) {
     return(invisible(proj_get_()))
   }
 
   path <- proj_path_prep(path)
   if (is.null(path) || force) {
     proj_string <- if (is.null(path)) "<no active project>" else path
-    ui_done("Setting active project to {ui_value(proj_string)}")
+    ui_bullets(c("v" = "Setting active project to {.val {proj_string}}."))
     return(proj_set_(path))
   }
 
   check_path_is_directory(path)
   new_project <- proj_find(path)
   if (is.null(new_project)) {
-    ui_stop(
-      "Path {ui_path(path)} does not appear to be inside a project or package."
-    )
+    ui_abort(c(
+      "Path {.path {pth(path)}} does not appear to be inside a project or package.",
+      "Read more in the help for {.fun usethis::proj_get}."
+    ))
   }
   proj_set(path = new_project, force = TRUE)
 }
 
-#' @describeIn proj_utils Builds a path within the active project returned by
+#' @describeIn proj_utils Builds paths within the active project returned by
 #'   `proj_get()`. Thin wrapper around [fs::path()].
 #' @inheritParams fs::path
 #' @export
 proj_path <- function(..., ext = "") {
+  has_absolute_path <- function(x) any(is_absolute_path(x))
+  dots <- list(...)
+  if (any(map_lgl(dots, has_absolute_path))) {
+    ui_abort("Paths must be relative to the active project, not absolute.")
+  }
+
   path_norm(path(proj_get(), ..., ext = ext))
 }
 
@@ -200,21 +212,23 @@ check_is_package <- function(whos_asking = NULL) {
     return(invisible())
   }
 
-  message <- "Project {ui_value(project_name())} is not an R package."
+  message <- "Project {.val {project_name()}} is not an R package."
   if (!is.null(whos_asking)) {
+    whos_asking_fn <- sub("()", "", whos_asking, fixed = TRUE)
     message <- c(
-      "{ui_code(whos_asking)} is designed to work with packages.",
-      message
+      "i" = "{.topic [{whos_asking}](usethis::{whos_asking_fn})} is designed to work with packages.",
+      "x" = message
     )
   }
-  ui_stop(message)
+  ui_abort(message)
 }
 
 check_is_project <- function() {
   if (!possibly_in_proj()) {
-    ui_stop("
-      We do not appear to be inside a valid project or package
-      Read more in the help for {ui_code(\"proj_get()\")}")
+    ui_abort(c(
+      "We do not appear to be inside a valid project or package.",
+      "Read more in the help for {.fun usethis::proj_get}."
+    ))
   }
 }
 
@@ -231,11 +245,6 @@ is_in_proj <- function(path) {
   )
 }
 
-package_data <- function(base_path = proj_get()) {
-  desc <- desc::description$new(base_path)
-  as.list(desc$get(desc$fields()))
-}
-
 project_name <- function(base_path = proj_get()) {
   ## escape hatch necessary to solve this chicken-egg problem:
   ## create_package() calls use_description(), which calls project_name()
@@ -246,7 +255,7 @@ project_name <- function(base_path = proj_get()) {
   }
 
   if (is_package(base_path)) {
-    package_data(base_path)$Package
+    proj_desc(base_path)$get_field("Package")
   } else {
     path_file(base_path)
   }
@@ -266,14 +275,18 @@ proj_activate <- function(path) {
   path <- user_path_prep(path)
 
   if (rstudio_available() && rstudioapi::hasFun("openProject")) {
-    ui_done("Opening {ui_path(path, base = NA)} in new RStudio session")
+    ui_bullets(c(
+      "v" = "Opening {.path {pth(path, base = NA)}} in new RStudio session."
+    ))
     rstudioapi::openProject(path, newSession = TRUE)
     invisible(FALSE)
   } else {
     proj_set(path)
     rel_path <- path_rel(proj_get(), path_wd())
     if (rel_path != ".") {
-      ui_done("Changing working directory to {ui_path(path, base = NA)}")
+      ui_bullets(c(
+        "v" = "Changing working directory to {.path {pth(path, base = NA)}}"
+      ))
       setwd(proj_get())
     }
     invisible(TRUE)
