@@ -6,27 +6,20 @@
 #'   * May create an initial placeholder `.c` or `.cpp` file
 #'   * Creates `Makevars` and `Makevars.win` files (`use_rcpp_armadillo()` only)
 #'
-#' @param name If supplied, creates and opens `src/name.{c,cpp}`.
-#'
-#' @details
-#'
-#' When using compiled code, please note that there must be at least one file
-#' inside the `src/` directory prior to building the package. As a result,
-#' if an empty `src/` directory is detected, either a `.c` or `.cpp` file will
-#' be added.
-#'
+#' @inheritParams use_r
 #' @export
 use_rcpp <- function(name = NULL) {
   check_is_package("use_rcpp()")
   check_uses_roxygen("use_rcpp()")
 
-  use_src()
-
   use_dependency("Rcpp", "LinkingTo")
   use_dependency("Rcpp", "Imports")
   roxygen_ns_append("@importFrom Rcpp sourceCpp") && roxygen_remind()
 
-  use_src_example_script(name, "cpp")
+  use_src()
+  path <- path("src", compute_name(name, "cpp"))
+  use_template("code.cpp", path)
+  edit_file(proj_path(path))
 
   invisible()
 }
@@ -68,7 +61,9 @@ use_c <- function(name = NULL) {
 
   use_src()
 
-  use_src_example_script(name, "c")
+  path <- path("src", compute_name(name, ext = "c"))
+  use_template("code.c", path)
+  edit_file(proj_path(path))
 
   invisible(TRUE)
 }
@@ -97,33 +92,20 @@ use_makevars <- function(settings = NULL) {
   if (!file_exists(makevars_path) && !file_exists(makevars_win_path)) {
     write_utf8(makevars_path, makevars_content)
     file_copy(makevars_path, makevars_win_path)
-    ui_done("Created {ui_path(makevars_path)} and {ui_path(makevars_win_path)} \\
-             with requested compilation settings.")
+    ui_bullets(c(
+      "v" = "Created {.path {pth(makevars_path)}} and
+             {.path {pth(makevars_win_path)}} with requested compilation settings."
+    ))
   } else {
-    ui_todo("Ensure the following Makevars compilation settings are set for both \\
-            {ui_path(makevars_path)} and {ui_path(makevars_win_path)}:")
-    ui_code_block(
-      makevars_content
+    ui_bullets(c(
+      "_" = "Ensure the following Makevars compilation settings are set for both
+             {.path {pth(makevars_path)}} and {.path {pth(makevars_win_path)}}:"
+    ))
+    ui_code_snippet(
+      makevars_content,
+      language = ""
     )
     edit_file(makevars_path)
     edit_file(makevars_win_path)
   }
 }
-
-use_src_example_script <- function(name = NULL, src_type = c("cpp", "c")) {
-  src_type <- match.arg(src_type)
-
-  if (!directory_has_files(path("src"))) {
-    name <- name %||% "code"
-  }
-
-  if (!is.null(name)) {
-    name <- slug(name, src_type)
-    check_file_name(name)
-    use_template(
-      slug("code", src_type),
-      path("src", name),
-      open = is_interactive()
-    )
-  }
-}
