@@ -25,8 +25,8 @@
 #' `.git/hooks/pre-commit`, which you can modify or even delete.
 #'
 #' @inheritParams use_template
-#' @seealso The [important files
-#'   section](https://r-pkgs.org/release.html#important-files) of [R
+#' @seealso The [other markdown files
+#'   section](https://r-pkgs.org/other-markdown.html) of [R
 #'   Packages](https://r-pkgs.org).
 #' @export
 #' @examples
@@ -60,8 +60,9 @@ use_readme_rmd <- function(open = rlang::is_interactive()) {
   }
 
   if (is_pkg && !data$on_github) {
-    ui_todo("
-      Update {ui_path('README.Rmd')} to include installation instructions.")
+    ui_bullets(c(
+      "_" = "Update {.path {pth('README.Rmd')}} to include installation instructions."
+    ))
   }
 
   if (uses_git()) {
@@ -96,8 +97,9 @@ use_readme_md <- function(open = rlang::is_interactive()) {
   )
 
   if (is_pkg && !data$on_github) {
-    ui_todo("
-      Update {ui_path('README.md')} to include installation instructions.")
+    ui_bullets(c(
+      "_" = "Update {.path {pth('README.md')}} to include installation instructions."
+    ))
   }
 
   invisible(new)
