@@ -16,9 +16,9 @@ use_roxygen_md <- function(overwrite = FALSE) {
   if (!uses_roxygen()) {
     roxy_ver <- as.character(utils::packageVersion("roxygen2"))
 
-    use_description_field("Roxygen", "list(markdown = TRUE)")
-    use_description_field("RoxygenNote", roxy_ver)
-    ui_todo("Run {ui_code('devtools::document()')}")
+    proj_desc_field_update("Roxygen", "list(markdown = TRUE)", overwrite = FALSE)
+    proj_desc_field_update("RoxygenNote", roxy_ver, overwrite = FALSE)
+    ui_bullets(c("_" = "Run {.run devtools::document()}."))
     return(invisible())
   }
 
@@ -29,39 +29,44 @@ use_roxygen_md <- function(overwrite = FALSE) {
   }
 
   if (isFALSE(already_setup) || isTRUE(overwrite)) {
-    use_description_field("Roxygen", "list(markdown = TRUE)", overwrite = TRUE)
+    proj_desc_field_update("Roxygen", "list(markdown = TRUE)", overwrite = TRUE)
 
     check_installed("roxygen2md")
-    ui_todo("
-      Run {ui_code('roxygen2md::roxygen2md()')} to convert existing Rd \\
-      comments to markdown")
+    ui_bullets(c(
+      "_" = "Run {.run roxygen2md::roxygen2md()} to convert existing Rd
+             comments to markdown."
+    ))
     if (!uses_git()) {
-      ui_todo("
-        Consider using Git for greater visibility into and control over the \\
-        conversion process")
+      ui_bullets(c(
+        "!" = "Consider using Git for greater visibility into and control over
+               the conversion process."
+      ))
     }
-    ui_todo("Run {ui_code('devtools::document()')} when you're done")
+    ui_bullets(c("_" = "Run {.run devtools::document()} when you're done."))
 
     return(invisible())
   }
 
-  ui_stop("
-    {ui_path('DESCRIPTION')} already has a {ui_field('Roxygen')} field
-    Delete it and try agan or call {ui_code('use_roxygen_md(overwrite = TRUE)')}")
+  ui_abort(c(
+    "DESCRIPTION already has a {.field Roxygen} field.",
+    "Delete that field and try again or call {.code use_roxygen_md(overwrite = TRUE)}."
+  ))
 
   invisible()
 }
 
 # FALSE: no Roxygen field
-# TRUE: plain old "list(markdown = TRUE)"
+# TRUE: matches regex targetting 'markdown = TRUE', with some whitespace slop
 # NA: everything else
 uses_roxygen_md <- function() {
-  if (!desc::desc_has_fields("Roxygen", file = proj_get())) {
+  desc <- proj_desc()
+
+  if (!desc$has_fields("Roxygen")) {
     return(FALSE)
   }
 
-  roxygen <- desc::desc_get("Roxygen", file = proj_get())[[1]]
-  if (identical(roxygen, "list(markdown = TRUE)")) {
+  roxygen <- desc$get_field("Roxygen", "")
+  if (grepl("markdown\\s*=\\s*TRUE", roxygen)) {
     TRUE
   } else {
     NA
@@ -69,12 +74,12 @@ uses_roxygen_md <- function() {
 }
 
 uses_roxygen <- function() {
-  desc::desc_has_fields("RoxygenNote", file = proj_get())
+  proj_desc()$has_fields("RoxygenNote")
 }
 
 roxygen_ns_append <- function(tag) {
   block_append(
-    glue("{ui_value(tag)}"),
+    tag,
     glue("#' {tag}"),
     path = proj_path(package_doc_path()),
     block_start = "## usethis namespace: start",
@@ -93,18 +98,20 @@ roxygen_ns_show <- function() {
 }
 
 roxygen_remind <- function() {
-  ui_todo("Run {ui_code('devtools::document()')} to update {ui_path('NAMESPACE')}")
+  ui_bullets(c(
+    "_" = "Run {.run devtools::document()} to update {.path {pth('NAMESPACE')}}."
+  ))
   TRUE
 }
 
 roxygen_update_ns <- function(load = is_interactive()) {
-  ui_done("Writing {ui_path('NAMESPACE')}")
+  ui_bullets(c("v" = "Writing {.path {pth('NAMESPACE')}}."))
   utils::capture.output(
     suppressMessages(roxygen2::roxygenise(proj_get(), "namespace"))
   )
 
   if (load) {
-    ui_done("Loading {project_name()}")
+    ui_bullets(c("v" = "Loading {.pkg {project_name()}}."))
     pkgload::load_all(path = proj_get(), quiet = TRUE)
   }
 
@@ -120,11 +127,10 @@ check_uses_roxygen <- function(whos_asking) {
     return(invisible())
   }
 
-  ui_stop(
-    "
-    Project {ui_value(project_name())} does not use roxygen2.
-    {ui_code(whos_asking)} can not work without it.
-    You might just need to run {ui_code('devtools::document()')} once, then try again.
-    "
-  )
+  whos_asking_fn <- sub("()", "", whos_asking, fixed = TRUE)
+  ui_abort(c(
+    "Package {.pkg {project_name()}} does not use roxygen2.",
+    "{.fun {whos_asking_fn}} can not work without it.",
+    "You might just need to run {.run devtools::document()} once, then try again."
+  ))
 }
