@@ -167,14 +167,14 @@ restart_rstudio <- function(message = NULL) {
   }
 
   if (!is.null(message)) {
-    ui_todo(message)
+    ui_bullets(message)
   }
 
   if (!rstudioapi::hasFun("openProject")) {
     return(FALSE)
   }
 
-  if (ui_nope("Restart now?")) {
+  if (ui_nah("Restart now?")) {
     return(FALSE)
   }
 
@@ -182,7 +182,7 @@ restart_rstudio <- function(message = NULL) {
 }
 
 rstudio_git_tickle <- function() {
-  if (rstudioapi::hasFun("executeCommand")) {
+  if (uses_git() && rstudioapi::hasFun("executeCommand")) {
     rstudioapi::executeCommand("vcsRefresh")
   }
   invisible()
@@ -225,7 +225,7 @@ use_rstudio_preferences <- function(...) {
       next
     }
 
-    ui_done("Setting RStudio preference {ui_field(name)} to {ui_value(val)}.")
+    ui_bullets(c("v" = "Setting RStudio preference {.field {name}} to {.val {val}}."))
     json[[name]] <- val
   }
 
