@@ -44,7 +44,12 @@
 #'   tidyverse conventions around GitHub issue label names and colours.
 #'
 #' * `use_tidy_upkeep_issue()` creates an issue containing a checklist of
-#'   actions to bring your package up to current tidyverse standards.
+#'   actions to bring your package up to current tidyverse standards. Also
+#'   records the current date in the `Config/usethis/last-upkeep` field in
+#'   `DESCRIPTION`.
+#'
+#' * `use_tidy_logo()` calls `use_logo()` on the appropriate hex sticker PNG
+#'   file at <https://github.com/rstudio/hex-stickers>.
 #'
 #' @section `use_tidy_style()`:
 #' Uses the [styler package](https://styler.r-lib.org) package to style all code
@@ -82,13 +87,15 @@ create_tidy_package <- function(path, copyright_holder = NULL) {
 
   use_cran_comments(open = FALSE)
 
-  ui_todo("In the new package, remember to do:")
-  ui_todo("{ui_code('use_git()')}")
-  ui_todo("{ui_code('use_github()')}")
-  ui_todo("{ui_code('use_tidy_github()')}")
-  ui_todo("{ui_code('use_tidy_github_actions()')}")
-  ui_todo("{ui_code('use_tidy_github_labels()')}")
-  ui_todo("{ui_code('use_pkgdown_github_pages()')}")
+  ui_bullets(c("i" = "In the new package, remember to do:"))
+  ui_code_snippet("
+    usethis::use_git()
+    usethis::use_github()
+    usethis::use_tidy_github()
+    usethis::use_tidy_github_actions()
+    usethis::use_tidy_github_labels()
+    usethis::use_pkgdown_github_pages()
+  ")
 
   proj_activate(path)
 }
@@ -97,7 +104,7 @@ create_tidy_package <- function(path, copyright_holder = NULL) {
 #' @export
 #' @rdname tidyverse
 use_tidy_description <- function() {
-  desc <- desc::description$new(file = proj_get())
+  desc <- proj_desc()
   tidy_desc(desc)
   desc$write()
 
@@ -129,33 +136,15 @@ use_tidy_dependencies <- function() {
   # add badges; we don't need the details
   ui_silence(use_lifecycle())
 
-
   # If needed, copy in lightweight purrr compatibility layer
-  if (!desc::desc(proj_get())$has_dep("purrr")) {
+  if (!proj_desc()$has_dep("purrr")) {
     use_directory("R")
-    use_github_file(
-      "r-lib/rlang",
-      path = "R/compat-purrr.R",
-      save_as = "R/compat-purrr.R"
-    )
+    use_standalone("r-lib/rlang", "purrr")
   }
 
   invisible()
 }
 
-#' @export
-#' @rdname tidyverse
-use_tidy_eval <- function() {
-  check_is_package("use_tidy_eval()")
-
-  use_dependency("roxygen2", "Suggests")
-  use_dependency("rlang", "Imports", min_version = "0.4.11")
-  new <- use_template("tidy-eval.R", "R/utils-tidy-eval.R")
-
-  ui_todo("Run {ui_code('devtools::document()')}")
-  return(invisible(new))
-}
-
 #' @export
 #' @rdname tidyverse
 use_tidy_contributing <- function() {
@@ -208,7 +197,7 @@ use_tidy_coc <- function() {
   }
 
   use_dot_github()
-  use_coc(contact = "codeofconduct@rstudio.com", path = ".github")
+  use_coc(contact = "codeofconduct@posit.co", path = ".github")
 }
 
 #' @export
@@ -246,8 +235,10 @@ use_tidy_style <- function(strict = TRUE) {
       strict = strict
     )
   }
-  ui_line()
-  ui_done("Styled project according to the tidyverse style guide")
+  ui_bullets(c(
+    " " = "",
+    "v" = "Styled project according to the tidyverse style guide."
+  ))
   invisible(styled)
 }
 
@@ -312,9 +303,10 @@ use_tidy_thanks <- function(repo_spec = NULL,
 
   from_timestamp <- as_timestamp(repo_spec, x = from) %||% "2008-01-01"
   to_timestamp <- as_timestamp(repo_spec, x = to)
-  ui_done("
-    Looking for contributors from {as.Date(from_timestamp)} to \\
-    {to_timestamp %||% 'now'}")
+  ui_bullets(c(
+    "i" = "Looking for contributors from {as.Date(from_timestamp)} to
+           {to_timestamp %||% 'now'}."
+  ))
 
   res <- gh::gh(
     "/repos/{owner}/{repo}/issues",
@@ -325,7 +317,7 @@ use_tidy_thanks <- function(repo_spec = NULL,
     .limit = Inf
   )
   if (length(res) < 1) {
-    ui_oops("No matching issues/PRs found")
+    ui_bullets(c("x" = "No matching issues/PRs found."))
     return(invisible())
   }
 
@@ -339,15 +331,18 @@ use_tidy_thanks <- function(repo_spec = NULL,
     res <- res[creation_time(res) <= as.POSIXct(to_timestamp)]
   }
   if (length(res) == 0) {
-    ui_line("No matching issues/PRs found.")
+    ui_bullets(c("x" = "No matching issues/PRs found."))
     return(invisible())
   }
 
   contributors <- sort(unique(map_chr(res, c("user", "login"))))
   contrib_link <- glue("[&#x0040;{contributors}](https://github.com/{contributors})")
 
-  ui_done("Found {length(contributors)} contributors:")
-  ui_code_block(glue_collapse(contrib_link, sep = ", ", last = ", and ") + glue("."))
+  ui_bullets(c("v" = "Found {length(contributors)} contributors:"))
+  ui_code_snippet(
+    glue_collapse(contrib_link, sep = ", ", last = ", and ") + glue("."),
+    language = ""
+  )
 
   invisible(contributors)
 }
@@ -362,13 +357,14 @@ as_timestamp <- function(repo_spec, x = NULL) {
   if (inherits(as_POSIXct, "POSIXct")) {
     return(x)
   }
-  ui_done("Resolving timestamp for ref {ui_value(x)}")
+  ui_bullets(c("v" = "Resolving timestamp for ref {.val {x}}."))
   ref_df(repo_spec, refs = x)$timestamp
 }
 
 ## returns a data frame on GitHub refs, defaulting to all releases
 ref_df <- function(repo_spec, refs = NULL) {
-  stopifnot(is_string(repo_spec))
+  check_name(repo_spec)
+  check_character(refs, allow_null = TRUE)
   refs <- refs %||% releases(repo_spec)
   if (is.null(refs)) {
     return(NULL)
@@ -391,7 +387,7 @@ ref_df <- function(repo_spec, refs = NULL) {
 
 ## returns character vector of release tag names
 releases <- function(repo_spec) {
-  stopifnot(is_string(repo_spec))
+  check_name(repo_spec)
   res <- gh::gh(
     "/repos/{owner}/{repo}/releases",
     owner = spec_owner(repo_spec), repo = spec_repo(repo_spec)
@@ -419,3 +415,23 @@ base_and_recommended <- function() {
     "survival", "tcltk", "tools", "utils"
   )
 }
+
+#' @rdname tidyverse
+#' @inheritParams use_logo
+#' @export
+use_tidy_logo <- function(geometry = "240x278", retina = TRUE) {
+  if (!is_posit_pkg()) {
+    ui_abort("This function only works for Posit packages.")
+  }
+
+  tf <- withr::local_tempfile(fileext = ".png")
+
+  gh::gh(
+    "/repos/rstudio/hex-stickers/contents/PNG/{pkg}.png/",
+    pkg = project_name(),
+    .destfile = tf,
+    .accept = "application/vnd.github.v3.raw"
+  )
+
+  use_logo(tf, geometry = geometry, retina = retina)
+}
