@@ -16,7 +16,7 @@ can_overwrite <- function(path) {
   }
 
   if (is_interactive()) {
-    ui_yeah("Overwrite pre-existing file {ui_path(path)}?")
+    ui_yep(c("!" = "Overwrite pre-existing file {.path {pth(path)}}?"))
   } else {
     FALSE
   }
@@ -24,13 +24,11 @@ can_overwrite <- function(path) {
 
 check_is_named_list <- function(x, nm = deparse(substitute(x))) {
   if (!is_list(x)) {
-    bad_class <- paste(class(x), collapse = "/")
-    ui_stop("{ui_code(nm)} must be a list, not {ui_value(bad_class)}.")
+    ui_abort("{.code {nm}} must be a list, not {.obj_type_friendly {x}}.")
   }
   if (!is_dictionaryish(x)) {
-    ui_stop(
-      "Names of {ui_code(nm)} must be non-missing, non-empty, and non-duplicated."
-    )
+    ui_abort(
+      "Names of {.code {nm}} must be non-missing, non-empty, and non-duplicated.")
   }
   x
 }
@@ -40,17 +38,10 @@ dots <- function(...) {
 }
 
 asciify <- function(x) {
-  stopifnot(is.character(x))
+  check_character(x)
   gsub("[^a-zA-Z0-9_-]+", "-", x)
 }
 
-slug <- function(x, ext) {
-  x_base <- path_ext_remove(x)
-  x_ext <- path_ext(x)
-  ext <- if (identical(tolower(x_ext), tolower(ext))) x_ext else ext
-  as.character(path_ext_set(x_base, ext))
-}
-
 compact <- function(x) {
   is_empty <- vapply(x, function(x) length(x) == 0, logical(1))
   x[!is_empty]
@@ -60,9 +51,6 @@ compact <- function(x) {
 is_installed <- function(pkg) {
   rlang::is_installed(pkg)
 }
-check_installed <- function(pkg) {
-  rlang::check_installed(pkg)
-}
 
 isFALSE <- function(x) {
   identical(x, FALSE)
@@ -92,32 +80,34 @@ is_online <- function(host) {
 year <- function() format(Sys.Date(), "%Y")
 
 pluck_lgl <- function(.x, ...) {
-  as_logical(purrr::pluck(.x, ..., .default = NA))
+  as.logical(purrr::pluck(.x, ..., .default = NA))
 }
 
 pluck_chr <- function(.x, ...) {
-  as_character(purrr::pluck(.x, ..., .default = NA))
+  as.character(purrr::pluck(.x, ..., .default = NA))
 }
 
 pluck_int <- function(.x, ...) {
-  as_integer(purrr::pluck(.x, ..., .default = NA))
+  as.integer(purrr::pluck(.x, ..., .default = NA))
 }
 
 is_windows <- function() {
   .Platform$OS.type == "windows"
 }
 
-check_string <- function(x, nm = deparse(substitute(x))) {
-  if (!is_string(x)) {
-    ui_stop("{ui_code(nm)} must be a string.")
-  }
-  x
+is_linux <- function() {
+  identical(tolower(Sys.info()[["sysname"]]), "linux")
 }
 
-maybe_string <- function(x, nm = deparse(substitute(x))) {
-  if (is.null(x)) {
-    x
-  } else {
-    check_string(x, nm = nm)
-  }
+# For stability of `stringsAsFactors` across versions
+data.frame <- function(..., stringsAsFactors = FALSE) {
+  base::data.frame(..., stringsAsFactors = stringsAsFactors)
+}
+
+# wrapper around check_name() from import-standalone-types-check.R
+# for the common case when NULL is allowed (often default)
+maybe_name <- function(x, ..., arg = caller_arg(x),
+                       call = caller_env()) {
+  check_name(x, ..., allow_null = TRUE,
+             arg = arg, call = call)
 }
