@@ -19,14 +19,13 @@ test_that("use_roxygen_md() adds DESCRIPTION fields to naive package", {
   expect_true(uses_roxygen_md())
 })
 
-test_that("use_roxygen_md() behaves for pre-existing Roxygen field", {
+test_that("use_roxygen_md() finds 'markdown = TRUE' in presence of other stuff", {
   skip_if_not_installed("roxygen2")
 
   pkg <- create_local_package()
-  desc::desc_set(Roxygen = 'list(markdown = TRUE, r6 = FALSE, load = "source")')
+  desc::desc_set(Roxygen = 'list(markdown = TRUE, r6 = FALSE, load = "source", roclets = c("collate", "namespace", "rd", "roxyglobals::global_roclet"))')
 
-  expect_error(use_roxygen_md(), "already has")
   local_check_installed()
-  expect_no_error(use_roxygen_md(overwrite = TRUE))
+  expect_no_error(use_roxygen_md())
   expect_true(uses_roxygen_md())
 })
