@@ -115,7 +115,7 @@ test_that("write_utf8() can operate outside of a project", {
   local_project(NULL)
 
   expect_false(proj_active())
-  expect_error_free(write_utf8(path = "foo", letters[1:3]))
+  expect_no_error(write_utf8(path = "foo", letters[1:3]))
 })
 
 # https://github.com/r-lib/usethis/issues/514
@@ -166,17 +166,88 @@ test_that("same_contents() detects if contents are / are not same", {
   expect_false(same_contents(tmp, letters[4:6]))
 })
 
-test_that("write_over() writes a de novo file", {
-  tmp <- file_temp()
-  expect_false(file_exists(tmp))
-  write_over(tmp, letters[1:3], quiet = TRUE)
-  expect_identical(read_utf8(tmp), letters[1:3])
+test_that("write_over() leaves file 'as is' (outside of a project)", {
+  local_interactive(FALSE)
+  tmp <- withr::local_file(file_temp())
+
+  writeLines(letters[1:3], tmp)
+
+  before <- read_utf8(tmp)
+  write_over(tmp, letters[4:6], quiet = TRUE)
+  expect_identical(read_utf8(tmp), before)
+
+  # usethis.overwrite shouldn't matter for a file outside of a project
+  withr::with_options(
+    list(usethis.overwrite = TRUE),
+    {
+      write_over(tmp, letters[4:6], quiet = TRUE)
+      expect_identical(read_utf8(tmp), before)
+    }
+  )
 })
 
-test_that("write_over() leaves file 'as is'", {
-  tmp <- file_temp()
+test_that("write_over() works in active project", {
+  local_interactive(FALSE)
+  create_local_project()
+
+  tmp <- proj_path("foo.txt")
   writeLines(letters[1:3], tmp)
+
   before <- read_utf8(tmp)
-  write_over(tmp, letters[1:3], quiet = TRUE)
-  expect_identical(before, read_utf8(tmp))
+  write_over(tmp, letters[4:6], quiet = TRUE)
+  expect_identical(read_utf8(tmp), before)
+
+  use_git()
+  withr::with_options(
+    list(usethis.overwrite = TRUE),
+    {
+      write_over(tmp, letters[4:6], quiet = TRUE)
+      expect_identical(read_utf8(tmp), letters[4:6])
+    }
+  )
+})
+
+test_that("write_over() works for a file in a project that is not active", {
+  local_interactive(FALSE)
+  owd <- getwd()
+  proj <- create_local_project()
+  use_git()
+
+  tmp <- proj_path("foo.txt")
+  writeLines(letters[1:3], tmp)
+
+  withr::local_dir(owd)
+  local_project(NULL)
+  expect_false(proj_active())
+
+  tmp <- path(proj, "foo.txt")
+  before <- read_utf8(tmp)
+
+  withr::with_options(
+    list(usethis.overwrite = FALSE),
+    {
+      write_over(tmp, letters[4:6], quiet = TRUE)
+      expect_identical(read_utf8(tmp), before)
+    }
+  )
+
+  withr::with_options(
+    list(usethis.overwrite = TRUE),
+    {
+      write_over(tmp, letters[4:6], quiet = TRUE)
+      expect_identical(read_utf8(tmp), letters[4:6])
+    }
+  )
+  expect_false(proj_active())
+})
+
+test_that("write_union() messaging is correct with weird working directory", {
+  create_local_project()
+  use_directory("aaa/bbb")
+  setwd("aaa/bbb")
+
+  withr::local_options(usethis.quiet = FALSE)
+  expect_snapshot(
+    write_union(proj_path("somefile"), letters[4:6])
+  )
 })
